/* $Id: holmes.h,v 1.4 2002/12/15 22:43:12 moocow Exp $
*/
#ifndef _RSYNTH_HOLMES_H
#define _RSYNTH_HOLMES_H

/**
 * \file holmes.h
 * \brief Part of Nick's implementation of a phoneme to "vocal tract parameters" system
 * described by J. N. Holmes, I. Mattingly, and J. Shearme, "Speech synthesis by rule".
 * Language and Speech 7, pp 127--143. 1964.
 */

/*-------------------------------------------------------------------
 * typedefs
 *-------------------------------------------------------------------*/

/// Slope structure for LPC (?)
typedef struct
{
  float v;                        ///< boundary value
  int t;                          ///< transition time
} holmes_slope_t;

/// LPC Parameter-transition structure.
typedef struct
{
  holmes_slope_t p[nEparm];       ///< Transition slopes for each element-parameter (see enum Eparm_e).
} holmes_trans_t;

/// LPC "filter" structure.
typedef struct
 {
  float a;
  float b;
  float v;
 } holmes_filter_t, *holmes_filter_ptr;


/*-------------------------------------------------------------------
 * function prototypes
 *-------------------------------------------------------------------*/

/**
 * \brief Phoneme to "vocal tract parameters" conversion.
 * @param synth Holds global flags and structures for conversion.
 * @param nelm Number of 'elements' to convert.
 * @param elm Elments to convert: actually a list of 3-tuples disguised as a char*:<br>
 *   \li \p i%3==0 : \p elm[i] is the element's index in global Elements[].
 *   \li \p i%3==1 : \p elm[i] is the duration of the element (in what?)
 *   \li \p i%3==2 : \p elm[i] is the element's stress-value (range?).
 * @param nsamp Number of samples to compute (?)
 * @param samp_base Pre-allocated sample buffer (?)
 */
extern unsigned holmes PROTO((rsynth_synth *synth,unsigned nelm,unsigned char *elm,unsigned nsamp, short *samp_base));

/// Holmes module configuration/initialization.
extern int init_holmes PROTO((rsynth_synth *synth,int argc,char *argv[]));

/// Holmes module reaper.
extern void term_holmes PROTO((rsynth_synth *synth));

#endif /* _RSYNTH_HOLMES_H */
